@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2022-2024 the Eask authors.
+ * Copyright (C) 2022-2025 the Eask authors.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@ exports.desc = 'Create a new package';
 exports.builder = yargs => yargs
   .positional(
     '<name>', {
-      description: 'new project name',
+      description: 'new package name',
       type: 'string',
     });
 
