@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2023-2024 the Eask authors.
+ * Copyright (C) 2023-2025 the Eask authors.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 "use strict";
 
 exports.command = ['delete [names..]', 'remove [names..]'];
-exports.desc = 'Delete local linked packages';
+exports.desc = 'Delete locally linked packages';
 exports.builder = yargs => yargs
   .positional(
     '[names..]', {
