@@ -479,10 +479,15 @@ You can pass BUFFER-OR-NAME to replace current buffer."
   (with-current-buffer (or buffer-or-name (current-buffer))
     (goto-char (point-min))
     (while (not (eobp))
-      (let ((line (buffer-substring-no-properties (line-beginning-position) (line-end-position))))
-        (cond ((string-match-p "[: ][Ee]rror: " line) (eask-error line))
-              ((string-match-p "[: ][Ww]arning: " line) (eask-warn line))
-              (t (eask-log line))))
+      (let ((line (buffer-substring-no-properties (line-beginning-position)
+                                                  (line-end-position))))
+        ;; The variable `line' can contains format specifier, avoid it with `%s'!
+        (cond ((string-match-p "[: ][Ee]rror: " line)
+               (eask-error "%s" line))
+              ((string-match-p "[: ][Ww]arning: " line)
+               (eask-warn "%s" line))
+              (t
+               (eask-log "%s" line))))
       (forward-line 1))))
 
 (defun eask-delete-file (filename)
@@ -1427,7 +1432,14 @@ This uses function `locate-dominating-file' to look up directory tree."
                  (ignore-errors (make-directory package-user-dir t))
                  (eask--silent (eask-setup-paths))
                  (eask-with-verbosity 'debug (eask--load-config))
-                 (eask--with-hooks ,@body))))))))))
+                 (eask--with-hooks ,@body))))))
+         ;; Report exit stats if any.
+         (eask--resolve-exit-status)))))
+
+(defun eask--resolve-exit-status ()
+  "Resolve current exit status."
+  (when (memq 'error (eask--error-status))
+    (eask--exit 'failure)))
 
 ;;
 ;;; Eask file
@@ -1821,7 +1833,8 @@ Execute forms BODY limit by the verbosity level (SYMBOL)."
 (defun eask--ansi (symbol string)
   "Paint STRING with color defined by log level (SYMBOL)."
   (if-let* ((ansi-function (cdr (assq symbol eask-level-color))))
-      (funcall ansi-function string)
+      ;; The `%s` is use to avoid `not enough arguments for string` error.
+      (funcall ansi-function "%s" string)
     string))
 
 (defun eask--format (prefix fmt &rest args)
@@ -1829,41 +1842,39 @@ Execute forms BODY limit by the verbosity level (SYMBOL)."
 
 Argument PREFIX is a string identify the type of this messages.  Arguments FMT
 and ARGS are used to pass through function `format'."
-  (apply #'format
-         (concat (when eask-timestamps (format-time-string "%Y-%m-%d %H:%M:%S "))
-                 (when eask-log-level (concat prefix " "))
-                 fmt)
-         args))
+  (concat (when eask-timestamps (format-time-string "%Y-%m-%d %H:%M:%S "))
+          (when eask-log-level (concat prefix " "))
+          (apply #'format fmt args)))
 
-(defun eask--msg (symbol prefix msg &rest args)
+(defun eask--msg (symbol prefix fmt &rest args)
   "If level (SYMBOL) is at or below `eask-verbosity'; then, log the message.
 
-For arguments PREFIX, MSG and ARGS, please see funtion `eask--format' for the
+For arguments PREFIX, FMT and ARGS, please see funtion `eask--format' for the
 detials."
   (eask-with-verbosity symbol
-    (let* ((string (apply #'eask--format prefix msg args))
-           (output (eask--ansi symbol string))
+    (let* ((output (apply #'eask--format prefix fmt args))
+           (output (eask--ansi symbol output))
            (output (eask--msg-displayable-kwds output))  ; Don't color, but replace it!
            (func (cl-case symbol
                    ((or error warn) symbol)
-                   (t #'message))))
+                   (t               #'message))))
       (funcall func "%s" output))))
 
-(defun eask-debug (msg &rest args)
-  "Send debug message; see function `eask--msg' for arguments MSG and ARGS."
-  (apply #'eask--msg 'debug "[DEBUG]" msg args))
-(defun eask-log (msg &rest args)
-  "Send log message; see function `eask--msg' for arguments MSG and ARGS."
-  (apply #'eask--msg 'log   "[LOG]" msg args))
-(defun eask-info (msg &rest args)
-  "Send info message; see function `eask--msg' for arguments MSG and ARGS."
-  (apply #'eask--msg 'info  "[INFO]" msg args))
-(defun eask-warn (msg &rest args)
-  "Send warn message; see function `eask--msg' for arguments MSG and ARGS."
-  (apply #'eask--msg 'warn  "[WARNING]" msg args))
-(defun eask-error (msg &rest args)
-  "Send error message; see function `eask--msg' for arguments MSG and ARGS."
-  (apply #'eask--msg 'error "[ERROR]" msg args))
+(defun eask-debug (fmt &rest args)
+  "Send debug message; see function `eask--msg' for arguments FMT and ARGS."
+  (apply #'eask--msg 'debug "[DEBUG]" fmt args))
+(defun eask-log (fmt &rest args)
+  "Send log message; see function `eask--msg' for arguments FMT and ARGS."
+  (apply #'eask--msg 'log   "[LOG]" fmt args))
+(defun eask-info (fmt &rest args)
+  "Send info message; see function `eask--msg' for arguments FMT and ARGS."
+  (apply #'eask--msg 'info  "[INFO]" fmt args))
+(defun eask-warn (fmt &rest args)
+  "Send warn message; see function `eask--msg' for arguments FMT and ARGS."
+  (apply #'eask--msg 'warn  "[WARNING]" fmt args))
+(defun eask-error (fmt &rest args)
+  "Send error message; see function `eask--msg' for arguments FMT and ARGS."
+  (apply #'eask--msg 'error "[ERROR]" fmt args))
 
 (defun eask--msg-char-displayable (char replacement s)
   "Ensure CHAR is displayable in S; if not, we fallback to REPLACEMENT
@@ -1942,7 +1953,7 @@ Argument ARGS are direct arguments for functions `eask-error' or `eask-warn'."
   `((success . 0)   ; Unused
     (failure . 1)   ; Catchall for general errors
     (misuse  . 2))
-  "Exit code specification.")
+  "The exit code specification.")
 
 (defun eask-exit-code (key)
   "Return the exit code by KEY symbol."
@@ -1963,6 +1974,12 @@ Argument ARGS are direct arguments for functions `eask-error' or `eask-warn'."
 (defvar eask-inhibit-error-message nil
   "Non-nil to stop error/warning message.")
 
+(defvar eask--has-error-p nil
+  "Non-nil if an error has occurred.")
+
+(defvar eask--has-warn-p nil
+  "Non-nil if a warning has occurred.")
+
 (defmacro eask-ignore-errors (&rest body)
   "Execute BODY without killing the process."
   (declare (indent 0) (debug t))
@@ -1978,13 +1995,38 @@ Argument ARGS are direct arguments for functions `eask-error' or `eask-warn'."
   (declare (indent 0) (debug t))
   `(eask-ignore-errors (eask--silent-error ,@body)))
 
-(defun eask--trigger-error ()
-  "Trigger error event."
+(defun eask--error-status ()
+  "Return error status."
+  (let ((result))
+    ;; Error.
+    (when eask--has-error-p
+      (push 'error result))
+    ;; Warning.
+    (when eask--has-warn-p
+      (push (if (eask-strict-p)
+                'error
+              'warn)
+            result))
+    ;; No repeat.
+    (delete-dups result)))
+
+(defun eask--trigger-error (args)
+  "Trigger error event.
+
+The argument ARGS is passed from the function `eask--error'."
+  (cond ((< emacs-major-version 28)
+         ;; Handle https://github.com/emacs-eask/cli/issues/11.
+         (unless (string-prefix-p "Can't find library " (car args))
+           (setq eask--has-error-p t)))
+        (t
+         (setq eask--has-error-p t)))  ; Just a record.
+
   (when (and (not eask--ignore-error-p)
-             (not (eask-checker-p)))  ; ignore when checking Eask-file
-    (if (eask-allow-error-p)  ; Trigger error at the right time
-        (add-hook 'eask-after-command-hook #'eask--exit)
-      (eask--exit))))
+             (not (eask-allow-error-p))
+             ;; Ignore when checking Eask-file.
+             (not (eask-checker-p)))
+    ;; Stop immediately.
+    (eask--exit 'failure)))
 
 (defun eask--error (fnc &rest args)
   "On error.
@@ -1994,9 +2036,13 @@ Arguments FNC and ARGS are used for advice `:around'."
     (unless eask-inhibit-error-message
       (eask--unsilent (eask-msg "%s" msg)))
     (run-hook-with-args 'eask-on-error-hook 'error msg)
-    (eask--trigger-error))
+    (eask--trigger-error args))
   (when debug-on-error (apply fnc args)))
 
+(defun eask--trigger-warn ()
+  "Trigger warning event."
+  (setq eask--has-warn-p t))  ; Just a record.
+
 (defun eask--warn (fnc &rest args)
   "On warn.
 
@@ -2004,7 +2050,8 @@ Arguments FNC and ARGS are used for advice `:around'."
   (let ((msg (eask--ansi 'warn (apply #'format-message args))))
     (unless eask-inhibit-error-message
       (eask--unsilent (eask-msg "%s" msg)))
-    (run-hook-with-args 'eask-on-warning-hook 'warn msg))
+    (run-hook-with-args 'eask-on-warning-hook 'warn msg)
+    (eask--trigger-warn))
   (eask--silent (apply fnc args)))
 
 ;; Don't pollute outer exection.
