@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2022-2024 the Eask authors.
+ * Copyright (C) 2022-2025 the Eask authors.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,10 +27,20 @@ global.IS_PKG = path.basename(process.execPath).startsWith('eask');
 global.EASK_HOMEDIR = os.homedir().replace(/\\/g, '/') + '/.eask/';
 
 global.EASK_EMACS = process.env.EMACS || process.env.EASK_EMACS || "emacs";
+process.env.EMACS = EASK_EMACS;  // Set back the value.
 
 /* Titles */
 global.TITLE_CMD_OPTION = 'Command Options:';
 global.TITLE_PROXY_OPTION = 'Proxy Options:';
 
+/* Exit Code
+ *
+ * This must match with the variable `eask--exit-code` in
+ * the file `lisp/_prepare.el`.
+ */
+global.EXIT_SUCCESS = 0;
+global.EXIT_FAILURE = 1;
+global.EXIT_MISUSE  = 2;
+
 /* CI */
 global.GITHUB_ACTIONS = (process.env.GITHUB_WORKSPACE !== undefined);
